summaryrefslogtreecommitdiff
path: root/sys/arch/i386
diff options
context:
space:
mode:
Diffstat (limited to 'sys/arch/i386')
-rw-r--r--sys/arch/i386/i386/autoconf.c8
-rw-r--r--sys/arch/i386/i386/machdep.c3
-rw-r--r--sys/arch/i386/include/cpu.h5
3 files changed, 6 insertions, 10 deletions
diff --git a/sys/arch/i386/i386/machdep.c b/sys/arch/i386/i386/machdep.c
index 2fd66ad6f09..30ff3a17f89 100644
--- a/sys/arch/i386/i386/machdep.c
+++ b/sys/arch/i386/i386/machdep.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: machdep.c,v 1.157 2001/05/05 20:56:38 art Exp $ */
+/* $OpenBSD: machdep.c,v 1.158 2001/05/05 22:33:45 art Exp $ */
/* $NetBSD: machdep.c,v 1.214 1996/11/10 03:16:17 thorpej Exp $ */
/*-
@@ -469,7 +469,6 @@ cpu_startup()
#endif
}
ioport_malloc_safe = 1;
- configure();
}
/*
diff --git a/sys/arch/i386/include/cpu.h b/sys/arch/i386/include/cpu.h
index 17d31917151..22d2c229e2a 100644
--- a/sys/arch/i386/include/cpu.h
+++ b/sys/arch/i386/include/cpu.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: cpu.h,v 1.35 2001/04/30 13:23:11 art Exp $ */
+/* $OpenBSD: cpu.h,v 1.36 2001/05/05 22:33:48 art Exp $ */
/* $NetBSD: cpu.h,v 1.35 1996/05/05 19:29:26 christos Exp $ */
/*-
@@ -174,9 +174,6 @@ extern int cpu_f00f_bug;
void fix_f00f __P((void));
#endif
-/* autoconf.c */
-void configure __P((void));
-
/* dkcsum.c */
void dkcsumattach __P((void));
diff --git a/sys/arch/i386/i386/autoconf.c b/sys/arch/i386/i386/autoconf.c
index 16c7f3423fe..865cc5bf524 100644
--- a/sys/arch/i386/i386/autoconf.c
+++ b/sys/arch/i386/i386/autoconf.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: autoconf.c,v 1.34 2001/04/30 13:23:11 art Exp $ */
+/* $OpenBSD: autoconf.c,v 1.35 2001/05/05 22:33:44 art Exp $ */
/* $NetBSD: autoconf.c,v 1.20 1996/05/03 19:41:56 christos Exp $ */
/*-
@@ -42,7 +42,7 @@
/*
* Setup the system to run on the current machine.
*
* Configure() is called at boot time and initializes the vba
* device tables and the memory controller monitoring. Available
* devices are determined (from possibilities mentioned in ioconf.c),
* and the drivers are initialized.
@@ -80,13 +80,13 @@ dev_t bootdev = 0; /* bootdevice, initialized in locore.s */
* Determine i/o configuration for a machine.
*/
void
-configure()
+cpu_configure()
{
startrtclock();
if (config_rootfound("mainbus", NULL) == NULL)
- panic("configure: mainbus not configured");
+ panic("cpu_configure: mainbus not configured");
printf("biomask %x netmask %x ttymask %x\n",
(u_short)imask[IPL_BIO], (u_short)imask[IPL_NET],
@@ -42,7 +42,7 @@
* Setup the system to run on the current machine.
*
- * Configure() is called at boot time and initializes the vba
+ * cpu_configure() is called at boot time and initializes the vba
* device tables and the memory controller monitoring. Available
* devices are determined (from possibilities mentioned in ioconf.c),